# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.0.0] - 2024-11-10

Initial release

### Added

- `[HTTP-Header]` cross-reference syntax
- `[RFC-1111]` cross-reference syntax
